@@ -282,19 +282,26 @@ void Account::validateToken()
         verify_credentials,
         true,
         this,
-        [=](QNetworkReply *reply) {
+        [this, verify_credentials](QNetworkReply *reply) {
             if (!reply->isFinished()) {
+                qCWarning(TOKODON_HTTP) << "Authentification reply not finished" << username() << verify_credentials;
+                Q_EMIT authenticated(false, {});
                 return;
             }
 
-            const auto doc = QJsonDocument::fromJson(reply->readAll());
+            const auto data = reply->readAll();
+            const auto doc = QJsonDocument::fromJson(data);
 
             if (!doc.isObject()) {
+                qCWarning(TOKODON_HTTP) << "Authentication reply is not json" << username() << verify_credentials << data;
+                Q_EMIT authenticated(false, {});
                 return;
             }
 
             const auto object = doc.object();
             if (!object.contains("source"_L1)) {
+                qCWarning(TOKODON_HTTP) << "Authentication reply does not contains source" << username() << verify_credentials;
+                Q_EMIT authenticated(false, {});
                 return;
             }
 
@@ -420,14 +427,22 @@ void Account::checkForFollowRequests()
 
 void Account::checkForUnreadNotifications()
 {
-    get(apiUrl(QStringLiteral("/api/v1/notifications/unread_count")), true, this, [this](QNetworkReply *reply) {
-        const auto unreadNotificationsObject = QJsonDocument::fromJson(reply->readAll());
-        const auto count = unreadNotificationsObject["count"_L1].toInt();
-        if (m_unreadNotificationsCount != count) {
-            m_unreadNotificationsCount = count;
-            Q_EMIT unreadNotificationsCountChanged();
-        }
-    });
+    get(
+        apiUrl(QStringLiteral("/api/v1/notifications/unread_count")),
+        true,
+        this,
+        [this](QNetworkReply *reply) {
+            const auto unreadNotificationsObject = QJsonDocument::fromJson(reply->readAll());
+            const auto count = unreadNotificationsObject["count"_L1].toInt();
+            if (m_unreadNotificationsCount != count) {
+                m_unreadNotificationsCount = count;
+                Q_EMIT unreadNotificationsCountChanged();
+            }
+        },
+        [](QNetworkReply *reply) {
+            Q_UNUSED(reply)
+            // This error can be safely ignored
+        });
 }
 
 void Account::updatePushNotifications()
