@@ -18,19 +18,22 @@ class NotificationModel : public AbstractTimelineModel
     Q_PROPERTY(QStringList excludeTypes READ excludeTypes WRITE setExcludesTypes NOTIFY excludeTypesChanged)
 
 public:
+    enum NotificationRoles { ReportRole = ExtraRole, RelationshipSeveranceEventRole, ModerationWarningRole };
+
     explicit NotificationModel(QObject *parent = nullptr);
 
-    int rowCount(const QModelIndex &parent) const override;
-    QVariant data(const QModelIndex &index, int role) const override;
+    [[nodiscard]] int rowCount(const QModelIndex &parent) const override;
+    [[nodiscard]] QVariant data(const QModelIndex &index, int role) const override;
+    [[nodiscard]] QHash<int, QByteArray> roleNames() const override;
 
     virtual void fillTimeline(const QUrl &next = {});
 
     /// Get a shared pointer to the underlying notification object at \p index
-    std::shared_ptr<Notification> internalData(const QModelIndex &index) const;
+    [[nodiscard]] std::shared_ptr<Notification> internalData(const QModelIndex &index) const;
 
     /// Returns the list of excluded notification types
     /// \see setExcludesTypes
-    QStringList excludeTypes() const;
+    [[nodiscard]] QStringList excludeTypes() const;
 
     /**
      * @brief Set the types of notifications to exclude.
@@ -41,6 +44,8 @@ public:
      */
     void setExcludesTypes(const QStringList &excludeTypes);
 
+    Q_INVOKABLE void markAllNotificationsAsRead();
+
 public Q_SLOTS:
     /**
      * @brief Reply to the notification at @p index.
@@ -88,12 +93,12 @@ Q_SIGNALS:
 
 protected:
     void fetchMore(const QModelIndex &parent) override;
-    bool canFetchMore(const QModelIndex &parent) const override;
+    [[nodiscard]] bool canFetchMore(const QModelIndex &parent) const override;
 
     QString m_timelineName;
     AccountManager *m_manager = nullptr;
 
     QList<std::shared_ptr<Notification>> m_notifications;
     QStringList m_excludeTypes;
-    QUrl m_next;
+    std::optional<QUrl> m_next;
 };
